@@ -1,15 +1,16 @@
 from battleship.client.client import (
     Client,
     ClientError,
-    ConnectionImpossible,
+    ConnectionEvent,
     RequestFailed,
-    SessionSubscription,
     Unauthorized,
 )
 from battleship.client.credentials import (
     CredentialsProvider,
     filesystem_credentials_provider,
 )
+from battleship.client.subscriptions import PlayerSubscription, SessionSubscription
+from battleship.client.websocket import ConnectionImpossible
 
 __all__ = [
     "Client",
@@ -20,4 +21,6 @@ __all__ = [
     "Unauthorized",
     "ConnectionImpossible",
     "ClientError",
+    "PlayerSubscription",
+    "ConnectionEvent",
 ]
