@@ -4,6 +4,7 @@ from battleship.tui.screens.join_game import JoinGame
 from battleship.tui.screens.lobby import Lobby
 from battleship.tui.screens.main_menu import MainMenu
 from battleship.tui.screens.multiplayer import Multiplayer
+from battleship.tui.screens.settings import Settings
 from battleship.tui.screens.singleplayer import Singleplayer
 from battleship.tui.screens.statistics import Statistics
 
@@ -16,4 +17,5 @@ __all__ = [
     "CreateGame",
     "JoinGame",
     "Statistics",
+    "Settings",
 ]
