@@ -2,9 +2,10 @@ from textual import on
 from textual.app import ComposeResult
 from textual.containers import Container
 from textual.screen import Screen
-from textual.widgets import Footer, Label, ListItem, ListView, Markdown
+from textual.widgets import Label, ListItem, ListView, Markdown
 
 from battleship.tui import screens
+from battleship.tui.widgets import AppFooter
 
 WELCOME_TEXT = """
 # Welcome to Battleship TUI!
@@ -12,22 +13,22 @@ WELCOME_TEXT = """
 Battleship TUI is an implementation of the classic Battleship game
 for your terminal.
 
-You can play against the AI or against a real player
+You can play against the computer or against a real player
 via network.
 """
 
 
 class MainMenu(Screen[None]):
     def compose(self) -> ComposeResult:
-        with Container(classes="main"):
-            yield Markdown(WELCOME_TEXT, classes="screen-help")
+        with Container(classes="container middle"):
+            yield Markdown(WELCOME_TEXT)
 
-            with ListView(classes="screen-content"):
+            with ListView():
                 yield ListItem(Label(":robot: Singleplayer"), id="singleplayer")
                 yield ListItem(Label(":man: Multiplayer"), id="multiplayer")
                 yield ListItem(Label(":wrench: Settings"), id="settings")
 
-        yield Footer()
+        yield AppFooter()
 
     @on(ListView.Selected, item="#singleplayer")
     def run_singleplayer(self) -> None:
@@ -36,3 +37,7 @@ class MainMenu(Screen[None]):
     @on(ListView.Selected, item="#multiplayer")
     def run_multiplayer(self) -> None:
         self.app.switch_screen(screens.Multiplayer())
+
+    @on(ListView.Selected, item="#settings")
+    def to_settings(self) -> None:
+        self.app.switch_screen(screens.Settings())
